# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_time_pb2 as v1_dot_rules_dot_delivery__time__pb2


class DeliveryTimeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryTimeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeCreate",
            request_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateResponse.FromString,
        )
        self.DeliveryTimeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeRead",
            request_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadResponse.FromString,
        )
        self.DeliveryTimeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeUpdate",
            request_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateResponse.FromString,
        )
        self.DeliveryTimeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeDelete",
            request_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteResponse.FromString,
        )


class DeliveryTimeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryTimeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryTimeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryTimeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeCreate,
            request_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateResponse.SerializeToString,
        ),
        "DeliveryTimeRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeRead,
            request_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadResponse.SerializeToString,
        ),
        "DeliveryTimeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateResponse.SerializeToString,
        ),
        "DeliveryTimeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeDelete,
            request_deserializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryTimeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryTimeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeCreate",
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeRead",
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeUpdate",
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeService/DeliveryTimeDelete",
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__pb2.DeliveryTimeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import uom_pb2 as v1_dot_sales_dot_uom__pb2


class UomServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UomCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomCreate",
            request_serializer=v1_dot_sales_dot_uom__pb2.UomCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_uom__pb2.UomCreateResponse.FromString,
        )
        self.UomRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomRead",
            request_serializer=v1_dot_sales_dot_uom__pb2.UomReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_uom__pb2.UomReadResponse.FromString,
        )
        self.UomUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomUpdate",
            request_serializer=v1_dot_sales_dot_uom__pb2.UomUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_uom__pb2.UomUpdateResponse.FromString,
        )
        self.UomDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomDelete",
            request_serializer=v1_dot_sales_dot_uom__pb2.UomDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_uom__pb2.UomDeleteResponse.FromString,
        )


class UomServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UomCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UomDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UomServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "UomCreate": grpc.unary_unary_rpc_method_handler(
            servicer.UomCreate,
            request_deserializer=v1_dot_sales_dot_uom__pb2.UomCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_uom__pb2.UomCreateResponse.SerializeToString,
        ),
        "UomRead": grpc.unary_unary_rpc_method_handler(
            servicer.UomRead,
            request_deserializer=v1_dot_sales_dot_uom__pb2.UomReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_uom__pb2.UomReadResponse.SerializeToString,
        ),
        "UomUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.UomUpdate,
            request_deserializer=v1_dot_sales_dot_uom__pb2.UomUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_uom__pb2.UomUpdateResponse.SerializeToString,
        ),
        "UomDelete": grpc.unary_unary_rpc_method_handler(
            servicer.UomDelete,
            request_deserializer=v1_dot_sales_dot_uom__pb2.UomDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_uom__pb2.UomDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.uom.UomService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class UomService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UomCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomCreate",
            v1_dot_sales_dot_uom__pb2.UomCreateRequest.SerializeToString,
            v1_dot_sales_dot_uom__pb2.UomCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomRead",
            v1_dot_sales_dot_uom__pb2.UomReadRequest.SerializeToString,
            v1_dot_sales_dot_uom__pb2.UomReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomUpdate",
            v1_dot_sales_dot_uom__pb2.UomUpdateRequest.SerializeToString,
            v1_dot_sales_dot_uom__pb2.UomUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UomDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.uom.UomService/UomDelete",
            v1_dot_sales_dot_uom__pb2.UomDeleteRequest.SerializeToString,
            v1_dot_sales_dot_uom__pb2.UomDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/procurement_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/stock/procurement_group.proto\x12+pro.omni.oms.api.v1.stock.procurement_group\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xac\x01\n\x10ProcurementGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmove_type\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"x\n\x1dProcurementGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmove_type\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1eProcurementGroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12X\n\x11procurement_group\x18\x02 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"\xf9\x02\n\x1bProcurementGroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xff\x01\n\x1cProcurementGroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12Y\n\x12procurement_groups\x18\x03 \x03(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"\xb1\x01\n\x1dProcurementGroupUpdateRequest\x12X\n\x11procurement_group\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1eProcurementGroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12X\n\x11procurement_group\x18\x02 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"c\n\x1dProcurementGroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1eProcurementGroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xeb\x05\n\x17ProcurementGroupService\x12\xb3\x01\n\x16ProcurementGroupCreate\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupCreateRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupCreateResponse"\x00\x12\xad\x01\n\x14ProcurementGroupRead\x12H.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupReadRequest\x1aI.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupReadResponse"\x00\x12\xb3\x01\n\x16ProcurementGroupUpdate\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupUpdateRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupUpdateResponse"\x00\x12\xb3\x01\n\x16ProcurementGroupDelete\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupDeleteRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.procurement_group_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PROCUREMENTGROUP"]._serialized_start = 166
    _globals["_PROCUREMENTGROUP"]._serialized_end = 338
    _globals["_PROCUREMENTGROUPCREATEREQUEST"]._serialized_start = 340
    _globals["_PROCUREMENTGROUPCREATEREQUEST"]._serialized_end = 460
    _globals["_PROCUREMENTGROUPCREATERESPONSE"]._serialized_start = 463
    _globals["_PROCUREMENTGROUPCREATERESPONSE"]._serialized_end = 660
    _globals["_PROCUREMENTGROUPREADREQUEST"]._serialized_start = 663
    _globals["_PROCUREMENTGROUPREADREQUEST"]._serialized_end = 1040
    _globals["_PROCUREMENTGROUPREADRESPONSE"]._serialized_start = 1043
    _globals["_PROCUREMENTGROUPREADRESPONSE"]._serialized_end = 1298
    _globals["_PROCUREMENTGROUPUPDATEREQUEST"]._serialized_start = 1301
    _globals["_PROCUREMENTGROUPUPDATEREQUEST"]._serialized_end = 1478
    _globals["_PROCUREMENTGROUPUPDATERESPONSE"]._serialized_start = 1481
    _globals["_PROCUREMENTGROUPUPDATERESPONSE"]._serialized_end = 1678
    _globals["_PROCUREMENTGROUPDELETEREQUEST"]._serialized_start = 1680
    _globals["_PROCUREMENTGROUPDELETEREQUEST"]._serialized_end = 1779
    _globals["_PROCUREMENTGROUPDELETERESPONSE"]._serialized_start = 1781
    _globals["_PROCUREMENTGROUPDELETERESPONSE"]._serialized_end = 1888
    _globals["_PROCUREMENTGROUPSERVICE"]._serialized_start = 1891
    _globals["_PROCUREMENTGROUPSERVICE"]._serialized_end = 2638
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/timezone.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/utilities/timezone.proto\x12&pro.omni.oms.api.v1.utilities.timezone\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc3\x01\n\x08Timezone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0e\n\x06offset\x18\x04 \x01(\x05\x12\x12\n\noffset_dst\x18\x05 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xb8\x01\n\x12TimezoneAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x12\n\noffset_dst\x18\x04 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa4\x01\n\x13TimezoneAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08timezone\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone"\xf1\x02\n\x13TimezoneReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x14TimezoneReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x43\n\ttimezones\x18\x03 \x03(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone"\x93\x01\n\x15TimezoneUpdateRequest\x12\x42\n\x08timezone\x18\x01 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x16TimezoneUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x42\n\x08timezone\x18\x02 \x01(\x0b\x32\x30.pro.omni.oms.api.v1.utilities.timezone.Timezone"[\n\x15TimezoneDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16TimezoneDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd2\x04\n\x0fTimezoneService\x12\x88\x01\n\x0bTimezoneAdd\x12:.pro.omni.oms.api.v1.utilities.timezone.TimezoneAddRequest\x1a;.pro.omni.oms.api.v1.utilities.timezone.TimezoneAddResponse"\x00\x12\x8b\x01\n\x0cTimezoneRead\x12;.pro.omni.oms.api.v1.utilities.timezone.TimezoneReadRequest\x1a<.pro.omni.oms.api.v1.utilities.timezone.TimezoneReadResponse"\x00\x12\x91\x01\n\x0eTimezoneUpdate\x12=.pro.omni.oms.api.v1.utilities.timezone.TimezoneUpdateRequest\x1a>.pro.omni.oms.api.v1.utilities.timezone.TimezoneUpdateResponse"\x00\x12\x91\x01\n\x0eTimezoneDelete\x12=.pro.omni.oms.api.v1.utilities.timezone.TimezoneDeleteRequest\x1a>.pro.omni.oms.api.v1.utilities.timezone.TimezoneDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.timezone_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TIMEZONE"]._serialized_start = 123
    _globals["_TIMEZONE"]._serialized_end = 318
    _globals["_TIMEZONEADDREQUEST"]._serialized_start = 321
    _globals["_TIMEZONEADDREQUEST"]._serialized_end = 505
    _globals["_TIMEZONEADDRESPONSE"]._serialized_start = 508
    _globals["_TIMEZONEADDRESPONSE"]._serialized_end = 672
    _globals["_TIMEZONEREADREQUEST"]._serialized_start = 675
    _globals["_TIMEZONEREADREQUEST"]._serialized_end = 1044
    _globals["_TIMEZONEREADRESPONSE"]._serialized_start = 1047
    _globals["_TIMEZONEREADRESPONSE"]._serialized_end = 1272
    _globals["_TIMEZONEUPDATEREQUEST"]._serialized_start = 1275
    _globals["_TIMEZONEUPDATEREQUEST"]._serialized_end = 1422
    _globals["_TIMEZONEUPDATERESPONSE"]._serialized_start = 1425
    _globals["_TIMEZONEUPDATERESPONSE"]._serialized_end = 1592
    _globals["_TIMEZONEDELETEREQUEST"]._serialized_start = 1594
    _globals["_TIMEZONEDELETEREQUEST"]._serialized_end = 1685
    _globals["_TIMEZONEDELETERESPONSE"]._serialized_start = 1687
    _globals["_TIMEZONEDELETERESPONSE"]._serialized_end = 1786
    _globals["_TIMEZONESERVICE"]._serialized_start = 1789
    _globals["_TIMEZONESERVICE"]._serialized_end = 2383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_shipper_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/v1/rules/delivery_shipper_delivery_method.proto\x12:pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method\x1a\x11\x63ommon/base.proto"\xb5\x01\n\x1d\x44\x65liveryShipperDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9d\x01\n*DeliveryShipperDeliveryMethodCreateRequest\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfe\x01\n+DeliveryShipperDeliveryMethodCreateResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x86\x03\n(DeliveryShipperDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x02\n)DeliveryShipperDeliveryMethodReadResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x03(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xea\x01\n*DeliveryShipperDeliveryMethodUpdateRequest\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfe\x01\n+DeliveryShipperDeliveryMethodUpdateResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"p\n*DeliveryShipperDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"x\n+DeliveryShipperDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x8c\x08\n$DeliveryShipperDeliveryMethodService\x12\xf8\x01\n#DeliveryShipperDeliveryMethodCreate\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodCreateRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodCreateResponse"\x00\x12\xf2\x01\n!DeliveryShipperDeliveryMethodRead\x12\x64.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodReadRequest\x1a\x65.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodReadResponse"\x00\x12\xf8\x01\n#DeliveryShipperDeliveryMethodUpdate\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodUpdateRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodUpdateResponse"\x00\x12\xf8\x01\n#DeliveryShipperDeliveryMethodDelete\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodDeleteRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_shipper_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPERDELIVERYMETHOD"]._serialized_start = 131
    _globals["_DELIVERYSHIPPERDELIVERYMETHOD"]._serialized_end = 312
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATEREQUEST"]._serialized_start = 315
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATEREQUEST"]._serialized_end = 472
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATERESPONSE"]._serialized_start = 475
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATERESPONSE"]._serialized_end = 729
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADREQUEST"]._serialized_start = 732
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADREQUEST"]._serialized_end = 1122
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADRESPONSE"]._serialized_start = 1125
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADRESPONSE"]._serialized_end = 1436
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1439
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1673
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1676
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1930
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1932
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETEREQUEST"]._serialized_end = 2044
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETERESPONSE"]._serialized_start = 2046
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2166
    _globals["_DELIVERYSHIPPERDELIVERYMETHODSERVICE"]._serialized_start = 2169
    _globals["_DELIVERYSHIPPERDELIVERYMETHODSERVICE"]._serialized_end = 3205
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import country_pb2 as v1_dot_stock_dot_country__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/stock/warehouse.proto\x12#pro.omni.oms.api.v1.stock.warehouse\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17v1/stock/location.proto\x1a\x1bv1/stock/picking_type.proto\x1a\x16v1/stock/country.proto"\xef\t\n\tWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12;\n\x07\x63ountry\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12\x14\n\x0c\x63ountry_code\x18\x05 \x01(\t\x12:\n\x16territory_matrix_value\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\t\x12\x12\n\ncomplement\x18\x08 \x01(\t\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x64\x65livery_steps\x18\n \x01(\t\x12\x17\n\x0freception_steps\x18\x0b \x01(\t\x12\x38\n\x12locality_available\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x46\n\x10view_location_id\x18\r \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x42\n\x0cloc_stock_id\x18\x0e \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12K\n\x15wh_input_stock_loc_id\x18\x0f \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12H\n\x12wh_qc_stock_loc_id\x18\x10 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12J\n\x14wh_pack_stock_loc_id\x18\x11 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12L\n\x16wh_output_stock_loc_id\x18\x12 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12G\n\nin_type_id\x18\x13 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12H\n\x0bint_type_id\x18\x14 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12I\n\x0cpick_type_id\x18\x15 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12I\n\x0cpack_type_id\x18\x16 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12H\n\x0bout_type_id\x18\x17 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12?\n\x0cobject_audit\x18\x18 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc3\x04\n\x16WarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12:\n\x16territory_matrix_value\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07\x61\x64\x64ress\x18\x05 \x01(\t\x12\x12\n\ncomplement\x18\x06 \x01(\t\x12\x16\n\x0e\x64\x65livery_steps\x18\x07 \x01(\t\x12\x17\n\x0freception_steps\x18\x08 \x01(\t\x12\x1a\n\x12locality_available\x18\t \x01(\t\x12\x18\n\x10view_location_id\x18\n \x01(\x05\x12\x14\n\x0cloc_stock_id\x18\x0b \x01(\x05\x12\x1d\n\x15wh_input_stock_loc_id\x18\x0c \x01(\x05\x12\x1a\n\x12wh_qc_stock_loc_id\x18\r \x01(\x05\x12\x1c\n\x14wh_pack_stock_loc_id\x18\x0e \x01(\x05\x12\x1e\n\x16wh_output_stock_loc_id\x18\x0f \x01(\x05\x12\x12\n\nin_type_id\x18\x10 \x01(\x05\x12\x13\n\x0bint_type_id\x18\x11 \x01(\x05\x12\x14\n\x0cpick_type_id\x18\x12 \x01(\x05\x12\x14\n\x0cpack_type_id\x18\x13 \x01(\x05\x12\x13\n\x0bout_type_id\x18\x14 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x15 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\twarehouse\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\xf2\x02\n\x14WarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x15WarehouseReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x42\n\nwarehouses\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\x93\x01\n\x16WarehouseUpdateRequest\x12\x41\n\twarehouse\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x41\n\twarehouse\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.stock.warehouse.Warehouse"\\\n\x16WarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17WarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd0\x04\n\x10WarehouseService\x12\x8e\x01\n\x0fWarehouseCreate\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseCreateRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseCreateResponse"\x00\x12\x88\x01\n\rWarehouseRead\x12\x39.pro.omni.oms.api.v1.stock.warehouse.WarehouseReadRequest\x1a:.pro.omni.oms.api.v1.stock.warehouse.WarehouseReadResponse"\x00\x12\x8e\x01\n\x0fWarehouseUpdate\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseUpdateRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseUpdateResponse"\x00\x12\x8e\x01\n\x0fWarehouseDelete\x12;.pro.omni.oms.api.v1.stock.warehouse.WarehouseDeleteRequest\x1a<.pro.omni.oms.api.v1.stock.warehouse.WarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSE"]._serialized_start = 225
    _globals["_WAREHOUSE"]._serialized_end = 1488
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_start = 1491
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_end = 2070
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_start = 2073
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_end = 2240
    _globals["_WAREHOUSEREADREQUEST"]._serialized_start = 2243
    _globals["_WAREHOUSEREADREQUEST"]._serialized_end = 2613
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_start = 2616
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_end = 2841
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_start = 2844
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_end = 2991
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_start = 2994
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_end = 3161
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_start = 3163
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_end = 3255
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_start = 3257
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_end = 3357
    _globals["_WAREHOUSESERVICE"]._serialized_start = 3360
    _globals["_WAREHOUSESERVICE"]._serialized_end = 3952
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class TerritoryMatrix(_message.Message):
    __slots__ = ["id", "sequence", "name", "code", "active", "country_id", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    sequence: int
    name: str
    code: str
    active: _wrappers_pb2.BoolValue
    country_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        sequence: _Optional[int] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        country_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixAddRequest(_message.Message):
    __slots__ = ["country_id", "sequence", "name", "code", "active", "context"]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    country_id: str
    sequence: int
    name: str
    code: str
    active: _wrappers_pb2.BoolValue
    context: _base_pb2.Context
    def __init__(
        self,
        country_id: _Optional[str] = ...,
        sequence: _Optional[int] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixAddResponse(_message.Message):
    __slots__ = ["response_standard", "territory_matrixes"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    territory_matrixes: TerritoryMatrix
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        territory_matrixes: _Optional[_Union[TerritoryMatrix, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "territory_matrixes"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    territory_matrixes: _containers.RepeatedCompositeFieldContainer[TerritoryMatrix]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        territory_matrixes: _Optional[_Iterable[_Union[TerritoryMatrix, _Mapping]]] = ...,
    ) -> None: ...

class TerritoryMatrixUpdateRequest(_message.Message):
    __slots__ = ["territory_matrix", "context"]
    TERRITORY_MATRIX_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    territory_matrix: TerritoryMatrix
    context: _base_pb2.Context
    def __init__(
        self,
        territory_matrix: _Optional[_Union[TerritoryMatrix, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "territory_matrixes"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    territory_matrixes: TerritoryMatrix
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        territory_matrixes: _Optional[_Union[TerritoryMatrix, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class TerritoryMatrixDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class TerritoryMatrixLoadRequest(_message.Message):
    __slots__ = ["country_code", "csv_name", "context"]
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    CSV_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    country_code: str
    csv_name: str
    context: _base_pb2.Context
    def __init__(
        self,
        country_code: _Optional[str] = ...,
        csv_name: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixLoadResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class TerritoryMatrixStructureRequest(_message.Message):
    __slots__ = ["territorymatrix", "parent_code", "context"]
    TERRITORYMATRIX_FIELD_NUMBER: _ClassVar[int]
    PARENT_CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    territorymatrix: TerritoryMatrix
    parent_code: str
    context: _base_pb2.Context
    def __init__(
        self,
        territorymatrix: _Optional[_Union[TerritoryMatrix, _Mapping]] = ...,
        parent_code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class TerritoryMatrixStructureResponse(_message.Message):
    __slots__ = ["response_standard", "territory_matrixes"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    territory_matrixes: _struct_pb2.ListValue
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        territory_matrixes: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import route_pb2 as v1_dot_stock_dot_route__pb2


class RouteServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RouteCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteCreate",
            request_serializer=v1_dot_stock_dot_route__pb2.RouteCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_route__pb2.RouteCreateResponse.FromString,
        )
        self.RouteRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteRead",
            request_serializer=v1_dot_stock_dot_route__pb2.RouteReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_route__pb2.RouteReadResponse.FromString,
        )
        self.RouteUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteUpdate",
            request_serializer=v1_dot_stock_dot_route__pb2.RouteUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_route__pb2.RouteUpdateResponse.FromString,
        )
        self.RouteDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteDelete",
            request_serializer=v1_dot_stock_dot_route__pb2.RouteDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_route__pb2.RouteDeleteResponse.FromString,
        )


class RouteServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RouteCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RouteDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_RouteServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "RouteCreate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteCreate,
            request_deserializer=v1_dot_stock_dot_route__pb2.RouteCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_route__pb2.RouteCreateResponse.SerializeToString,
        ),
        "RouteRead": grpc.unary_unary_rpc_method_handler(
            servicer.RouteRead,
            request_deserializer=v1_dot_stock_dot_route__pb2.RouteReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_route__pb2.RouteReadResponse.SerializeToString,
        ),
        "RouteUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.RouteUpdate,
            request_deserializer=v1_dot_stock_dot_route__pb2.RouteUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_route__pb2.RouteUpdateResponse.SerializeToString,
        ),
        "RouteDelete": grpc.unary_unary_rpc_method_handler(
            servicer.RouteDelete,
            request_deserializer=v1_dot_stock_dot_route__pb2.RouteDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_route__pb2.RouteDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.route.RouteService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class RouteService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RouteCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteCreate",
            v1_dot_stock_dot_route__pb2.RouteCreateRequest.SerializeToString,
            v1_dot_stock_dot_route__pb2.RouteCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteRead",
            v1_dot_stock_dot_route__pb2.RouteReadRequest.SerializeToString,
            v1_dot_stock_dot_route__pb2.RouteReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteUpdate",
            v1_dot_stock_dot_route__pb2.RouteUpdateRequest.SerializeToString,
            v1_dot_stock_dot_route__pb2.RouteUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RouteDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.route.RouteService/RouteDelete",
            v1_dot_stock_dot_route__pb2.RouteDeleteRequest.SerializeToString,
            v1_dot_stock_dot_route__pb2.RouteDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Quant(_message.Message):
    __slots__ = [
        "id",
        "product_id",
        "location_id",
        "lote",
        "available_quantity",
        "quantity",
        "uom_id",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOTE_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    product_id: int
    location_id: int
    lote: str
    available_quantity: float
    quantity: float
    uom_id: int
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        product_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        lote: _Optional[str] = ...,
        available_quantity: _Optional[float] = ...,
        quantity: _Optional[float] = ...,
        uom_id: _Optional[int] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class QuantCreateRequest(_message.Message):
    __slots__ = [
        "product_id",
        "location_id",
        "lote",
        "available_quantity",
        "quantity",
        "uom_id",
        "reserved_quantity",
        "context",
    ]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    LOTE_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    UOM_ID_FIELD_NUMBER: _ClassVar[int]
    RESERVED_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    product_id: int
    location_id: int
    lote: str
    available_quantity: float
    quantity: float
    uom_id: int
    reserved_quantity: float
    context: _base_pb2.Context
    def __init__(
        self,
        product_id: _Optional[int] = ...,
        location_id: _Optional[int] = ...,
        lote: _Optional[str] = ...,
        available_quantity: _Optional[float] = ...,
        quantity: _Optional[float] = ...,
        uom_id: _Optional[int] = ...,
        reserved_quantity: _Optional[float] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantCreateResponse(_message.Message):
    __slots__ = ["response_standard", "quant"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    quant: Quant
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
    ) -> None: ...

class QuantReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "quants"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    QUANTS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    quants: _containers.RepeatedCompositeFieldContainer[Quant]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        quants: _Optional[_Iterable[_Union[Quant, _Mapping]]] = ...,
    ) -> None: ...

class QuantUpdateRequest(_message.Message):
    __slots__ = ["quant", "context"]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    quant: Quant
    context: _base_pb2.Context
    def __init__(
        self,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QuantUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "quant"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    QUANT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    quant: Quant
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        quant: _Optional[_Union[Quant, _Mapping]] = ...,
    ) -> None: ...

class QuantDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class QuantDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class ProductAvailable(_message.Message):
    __slots__ = ["available", "available_quantity"]
    AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    available: bool
    available_quantity: float
    def __init__(self, available: bool = ..., available_quantity: _Optional[float] = ...) -> None: ...

class ProductAvailableRequest(_message.Message):
    __slots__ = ["location_id", "product_id", "product_sku", "required_quantity", "context"]
    LOCATION_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SKU_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_QUANTITY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    location_id: int
    product_id: str
    product_sku: str
    required_quantity: int
    context: _base_pb2.Context
    def __init__(
        self,
        location_id: _Optional[int] = ...,
        product_id: _Optional[str] = ...,
        product_sku: _Optional[str] = ...,
        required_quantity: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ProductAvailableResponse(_message.Message):
    __slots__ = ["response_standard", "product_available"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_AVAILABLE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    product_available: ProductAvailable
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        product_available: _Optional[_Union[ProductAvailable, _Mapping]] = ...,
    ) -> None: ...



import hashlib
import json
import math
import secrets
import string
import unicodedata
from functools import reduce

DEFAULT_RECORD_LIMIT = 10000


def generate_strong_password(length=12):
    if length < 8:
        raise ValueError("The password length must be at least 8 characters.")

    punctuation = "!#$%&()*?@[]}{"
    characters = string.ascii_letters + string.digits + punctuation

    password = [
        secrets.choice(string.ascii_lowercase),
        secrets.choice(string.ascii_uppercase),
        secrets.choice(string.digits),
        secrets.choice(punctuation),
    ]

    for _ in range(length - 4):
        password.append(secrets.choice(characters))

    secrets.SystemRandom().shuffle(password)
    password_str = "".join(password)

    return password_str


def nested(data: dict, keys: str, default=None):
    """
    Receives a dictionary and a list of keys, and returns the value associated with the keys in order,
    searching the dictionary to any depth, not including lists. in order, searching the dictionary to
    any depth, not including lists. If the key is not found, it returns the default value.
    """
    return reduce(lambda d, key: d.get(key, default) if isinstance(d, dict) else default, keys.split("."), data)


def deep_search(lst, key=None, value=None, default=None):
    """
    Searches an item in a list in depth by key or value.

    Args:
        lst (list): the list to search.
        key (str): The key to search for.
        value: The value to search for.

    Returns:
        The element found or None if it was not found.
    """
    if isinstance(lst, dict):
        if key in lst and lst[key] == value:
            return lst
        for v in lst.values():
            if isinstance(v, (dict, list)):
                result = deep_search(v, key=key, value=value)
                if result is not None:
                    return result
    elif isinstance(lst, list):
        for elem in lst:
            if isinstance(elem, (dict, list)):
                result = deep_search(elem, key=key, value=value)
                if result is not None:
                    return result
            elif key is None and elem == value:
                return elem
            elif isinstance(elem, dict) and key in elem and elem[key] == value:
                return elem
    return default


def load_file_module(file_path: str, class_name: str):
    """
    Loads a module from a file.

    Args:
        file_path (str): The path to the file.
        class_name (str): The name of the class.

    Returns:
        The module loaded.
    """
    import importlib.util

    spec = importlib.util.spec_from_file_location(class_name, file_path)
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    return module


def paginate_list(objects_list, page_num, per_page, filters=None):
    filtered_list = objects_list
    if filters:
        filtered_list = [o for o in objects_list if o.attr == filters["attr"]]
    start = (page_num - 1) * per_page
    end = start + per_page
    paginated_list = filtered_list[start:end]
    total_pages = int(math.ceil(len(filtered_list) / per_page))
    return paginated_list, total_pages


def parse_bool(value):
    if isinstance(value, bool):
        return value
    if isinstance(value, str):
        return value.lower() in ("yes", "true", "t", "1", "y")
    return bool(value)


def to_camel_case(text: str):
    # Divide el texto por guiones bajos y une cada palabra con la primera letra en mayúsculas
    return "".join(word.capitalize() for word in text.split("_"))


def normalize(value):
    return unicodedata.normalize("NFKD", str(value).strip()).encode("ascii", "ignore").decode("UTF-8")


class HTTPStatus(object):
    OK = 200
    CREATED = 201
    ACCEPTED = 202
    NO_CONTENT = 204
    BAD_REQUEST = 400
    UNAUTHORIZED = 401
    FORBIDDEN = 403
    NOT_FOUND = 404
    METHOD_NOT_ALLOWED = 405
    CONFLICT = 409
    UNPROCESSABLE_ENTITY = 422
    INTERNAL_SERVER_ERROR = 500


class Resource(object):
    AWS_COGNITO = "cognito"
    MONGODB = "mongodb"
    POSTGRES = "postgres"


def generate_hash(obj):
    # Convertir el objeto a una cadena con claves ordenadas
    obj_str = json.dumps(obj, sort_keys=True)

    # Generar un hash SHA-256
    return hashlib.sha256(obj_str.encode()).hexdigest()



from typing import ClassVar as _ClassVar
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Address(_message.Message):
    __slots__ = [
        "country_id",
        "code",
        "name",
        "type_address",
        "street",
        "street2",
        "lat",
        "lng",
        "zip_code",
        "territory_matrixes",
        "active",
        "object_audit",
    ]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STREET_FIELD_NUMBER: _ClassVar[int]
    STREET2_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LNG_FIELD_NUMBER: _ClassVar[int]
    ZIP_CODE_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    country_id: str
    code: str
    name: str
    type_address: str
    street: str
    street2: str
    lat: str
    lng: str
    zip_code: str
    territory_matrixes: _struct_pb2.ListValue
    active: bool
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        country_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type_address: _Optional[str] = ...,
        street: _Optional[str] = ...,
        street2: _Optional[str] = ...,
        lat: _Optional[str] = ...,
        lng: _Optional[str] = ...,
        zip_code: _Optional[str] = ...,
        territory_matrixes: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        active: bool = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class AddressCreateRequest(_message.Message):
    __slots__ = [
        "client_id",
        "country_id",
        "code",
        "name",
        "type_address",
        "street",
        "street2",
        "lat",
        "lng",
        "zip_code",
        "territory_matrixes",
        "context",
    ]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STREET_FIELD_NUMBER: _ClassVar[int]
    STREET2_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LNG_FIELD_NUMBER: _ClassVar[int]
    ZIP_CODE_FIELD_NUMBER: _ClassVar[int]
    TERRITORY_MATRIXES_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    country_id: str
    code: str
    name: str
    type_address: str
    street: str
    street2: str
    lat: str
    lng: str
    zip_code: str
    territory_matrixes: _struct_pb2.ListValue
    context: _base_pb2.Context
    def __init__(
        self,
        client_id: _Optional[str] = ...,
        country_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        type_address: _Optional[str] = ...,
        street: _Optional[str] = ...,
        street2: _Optional[str] = ...,
        lat: _Optional[str] = ...,
        lng: _Optional[str] = ...,
        zip_code: _Optional[str] = ...,
        territory_matrixes: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressCreateResponse(_message.Message):
    __slots__ = ["response_standard", "address"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    address: Address
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        address: _Optional[_Union[Address, _Mapping]] = ...,
    ) -> None: ...

class AddressUpdateRequest(_message.Message):
    __slots__ = ["client_id", "address", "context"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    address: Address
    context: _base_pb2.Context
    def __init__(
        self,
        client_id: _Optional[str] = ...,
        address: _Optional[_Union[Address, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "address"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    address: Address
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        address: _Optional[_Union[Address, _Mapping]] = ...,
    ) -> None: ...

class AddressDeleteRequest(_message.Message):
    __slots__ = ["client_id", "code", "context"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    code: str
    context: _base_pb2.Context
    def __init__(
        self,
        client_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AddressDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...
